==> kubernetes-model-1.0.54-sources.jar: annotations/io/fabric8/openshift/api/model/ImageSourcePathBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ImageSourcePathBuilder extends ImageSourcePathFluentImpl<ImageSourcePathBuilder> implements VisitableBuilder<ImageSourcePath,ImageSourcePathBuilder>{

    ImageSourcePathFluent<?> fluent;
    Boolean validationEnabled;

    public ImageSourcePathBuilder(){
            this(true);
    }
    public ImageSourcePathBuilder(Boolean validationEnabled){
            this(new ImageSourcePath(), validationEnabled);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent){
            this(fluent, true);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageSourcePath(), validationEnabled);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,ImageSourcePath instance){
            this(fluent, instance, true);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,ImageSourcePath instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDestinationDir(instance.getDestinationDir()); 
            fluent.withSourcePath(instance.getSourcePath()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageSourcePathBuilder(ImageSourcePath instance){
            this(instance,true);
    }
    public ImageSourcePathBuilder(ImageSourcePath instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSourcePath(instance.getSourcePath()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageSourcePath build(){
            ImageSourcePath buildable = new ImageSourcePath(fluent.getDestinationDir(),fluent.getSourcePath());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageSourcePathBuilder that = (ImageSourcePathBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/openshift/api/model/ImageSourcePathBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ImageSourcePathBuilder extends ImageSourcePathFluentImpl<ImageSourcePathBuilder> implements VisitableBuilder<ImageSourcePath,ImageSourcePathBuilder>{

    ImageSourcePathFluent<?> fluent;
    Boolean validationEnabled;

    public ImageSourcePathBuilder(){
            this(true);
    }
    public ImageSourcePathBuilder(Boolean validationEnabled){
            this(new ImageSourcePath(), validationEnabled);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent){
            this(fluent, true);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageSourcePath(), validationEnabled);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,ImageSourcePath instance){
            this(fluent, instance, true);
    }
    public ImageSourcePathBuilder(ImageSourcePathFluent<?> fluent,ImageSourcePath instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDestinationDir(instance.getDestinationDir()); 
            fluent.withSourcePath(instance.getSourcePath()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageSourcePathBuilder(ImageSourcePath instance){
            this(instance,true);
    }
    public ImageSourcePathBuilder(ImageSourcePath instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSourcePath(instance.getSourcePath()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageSourcePath build(){
            ImageSourcePath buildable = new ImageSourcePath(fluent.getDestinationDir(),fluent.getSourcePath());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageSourcePathBuilder that = (ImageSourcePathBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
